OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Конфіденційність",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Центр конфіденційності показує, де зберігаються ваші дані та хто може отримати до них доступ, оскільки ви поділилися з ними або тому, що вони адміністратори.",
    "Remove external admin" : "Вилучити зовнішнього адміністратора",
    "Add external admin" : "Додати зовнішнього адміністратора",
    "Name of external admin" : "Ім'я зовнішнього адміністратора",
    "This server is using full-disk-encryption." : "Цей сервер використовує повне шифрування диска.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Ваше домашнє сховище зашифровано за допомогою {linkopen}шифрування на стороні сервера ↗{linkclose} за допомогою головного ключа.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Ваші файли на зовнішніх носіях можуть бути зашифровані за допомогою {linkopen}шифрування на стороні сервера ↗{linkclose} за допомогою головного ключа на основі їх конфігурації.",
    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Ваше домашнє сховище зашифровано за допомогою {linkopen}шифрування на стороні сервера ↗{linkclose} індивідуальним ключем користувача.",
    "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Ваші файли на зовнішніх носіях можуть бути зашифровані за допомогою {linkopen}шифрування на стороні сервера ↗{linkclose} з індивідуальним ключем на основі їх конфігурації.",
    "Additionally, this server is protected with full-disk-encryption." : "Крім того, цей сервер захищено повним дисковим шифруванням.",
    "This server is protected with full-disk-encryption." : "Цей сервер захищено повним дисковим шифруванням.",
    "Your files are not protected by encryption." : "Ваші файли не захищені шифруванням.",
    "Your data is located in:" : "Ваші дані знаходяться в:",
    "The admin has not selected the location of the server yet." : "Адмін ще не вибрав місце розташування сервера.",
    "Change data location" : "Змінити розташування даних",
    "Please select a region" : "Виберіть регіон",
    "You don't have any shares with individual users." : "У вас немає спільного доступу до окремих користувачів.",
    "Somaliland" : "Сомаліленд",
    "Andorra" : "Андорра",
    "United Arab Emirates" : "Об'єднані Арабські Емірати",
    "Afghanistan" : "Афганістан",
    "Antigua and Barbuda" : "Антигуа та Барбуда",
    "Anguilla" : "Ангілья ",
    "Albania" : "Албанія ",
    "Armenia" : "Вірменія",
    "Angola" : "Ангола ",
    "Antarctica" : "Антарктида",
    "Argentina" : "Аргентина ",
    "American Samoa" : "Американське Самоа ",
    "Austria" : "Австрія ",
    "Australia" : "Австралія ",
    "Aruba" : "Аруба ",
    "Åland Islands" : "Аландські острови ",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Боснія і Герцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Бельгія ",
    "Burkina Faso" : "Буркіна-Фасо",
    "Bulgaria" : "Болгарія ",
    "Bahrain" : "Бахрейн ",
    "Burundi" : "Бурунді ",
    "Benin" : "Бенін",
    "Saint Barthélemy" : "Сен-Бартелемі ",
    "Bermuda" : "Бермудські острови",
    "Brunei" : "Бруней",
    "Bolivia" : "Болівія",
    "Bonaire, Sint Eustatius and Saba" : "Бонайре, Сінт-Естатіус і Саба",
    "Brazil" : "Бразилія ",
    "Bahamas" : "Багамські острови",
    "Bhutan" : "Бутан ",
    "Bouvet Island" : "Буве",
    "Botswana" : "Ботсвана ",
    "Belarus" : "Білорусь",
    "Belize" : "Беліз ",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосові (Кілінгові) острови ",
    "Democratic Republic of the Congo" : "Демократична Республіка Конго",
    "Central African Republic" : "Центральноафриканська Республіка ",
    "Congo" : "Конго ",
    "Switzerland" : "Швейцарія ",
    "Cote d'Ivoire" : "Кот д'Івуар",
    "Cook Islands" : "Острови Кука",
    "Chile" : "Чилі ",
    "Cameroon" : "Камерун ",
    "China" : "Китай ",
    "Colombia" : "Колумбія ",
    "Costa Rica" : "Коста-Ріка ",
    "Cuba" : "Куба ",
    "Cabo Verde" : "Кабо-Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "Острів Різдва ",
    "Cyprus" : "Кіпр ",
    "Czech" : "Чехія",
    "Germany" : "Німеччина ",
    "Djibouti" : "Джибуті ",
    "Denmark" : "Данія ",
    "Dominican Republic" : "Домініканська Республіка ",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естонія",
    "Egypt" : "Єгипет",
    "West Sahara" : "Західна Сахара",
    "Eritrea" : "Еритрея",
    "Spain" : "Іспанія",
    "Ethiopia" : "Ефіопія",
    "Finland" : "Фінляндія",
    "Fiji" : "Фіджі",
    "Falkland Islands" : "Фолклендські острови",
    "Micronesia" : "Мікронезія",
    "Faroe Islands" : "Фарерські острови ",
    "France" : "Франція",
    "Gabon" : "Габон",
    "United Kingdom" : "Об'єднане Королівство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузія",
    "French Guiana" : "Французька Гвіана ",
    "Guernsey" : "Гернсі",
    "Ghana" : "Гана",
    "Gibraltar" : "Гібралтар",
    "Greenland" : "Гренландія",
    "Gambia" : "Гамбія",
    "Guinea" : "Гвінея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Екваторіальна Гвінея ",
    "Greece" : "Греція",
    "South Georgia and the South Sandwich Islands" : "Південна Георгія та Південні Сандвічеві острови ",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвінея-Бісау ",
    "Guyana" : "Гайана",
    "Honduras" : "Гондурас",
    "Hong Kong" : "Гонконг",
    "Heard Island and McDonald Islands" : "Острови Герд і Макдональд",
    "Croatia" : "Хорватія",
    "Haiti" : "Гаїті",
    "Hungary" : "Угорщина",
    "Indonesia" : "Індонезія",
    "Ireland" : "Ірландія",
    "Israel" : "Ізраїль",
    "Isle of Man" : "Острів Мен",
    "India" : "Індія",
    "British Indian Ocean Territory" : "Британська територія в Індійському океані ",
    "Iraq" : "Ірак",
    "Iran" : "Іран",
    "Iceland" : "Ісландія",
    "Italy" : "Італія",
    "Jamaica" : "Ямайка",
    "Jordan" : "Йорданія",
    "Japan" : "Японія",
    "Kenya" : "Кенія",
    "Kyrgyzstan" : "Киргизстан",
    "Cambodia" : "Камбоджа",
    "Kiribati" : "Кірибаті",
    "Comores" : "Коморські острови",
    "Saint Kitts and Nevis" : "Сент-Кіттс і Невіс",
    "North Korea" : "Північна Корея",
    "South Korea" : "Південна Корея",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманові острови ",
    "Kazakhstan" : "Казахстан",
    "Laos" : "Лаос",
    "Lebanon" : "Ліван",
    "Saint Lucia" : "Сент-Люсія ",
    "Liechtenstein" : "Ліхтенштейн",
    "Sri Lanka" : "Шрі-Ланка ",
    "Liberia" : "Ліберія",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвія",
    "Libya" : "Лівія",
    "Morocco" : "Марокко",
    "Monaco" : "Монако",
    "Moldova" : "Молдова",
    "Montenegro" : "Чорногорія",
    "Saint Martin" : "Святий Мартін",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршаллові острови",
    "Macedonia" : "Македонія",
    "Mali" : "Малі",
    "Myanmar" : "М'янма",
    "Mongolia" : " Монголія ",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Північні Маріанські острови",
    "Mauritania" : "Мавританія",
    "Montserrat" : "Монтсеррат",
    "Malta" : "Мальта",
    "Mauritius" : "Маврикій",
    "Maldives" : "Мальдіви",
    "Malawi" : "Малаві",
    "Mexico" : "Мексика",
    "Malaysia" : "Малайзія",
    "Mozambique" : "Мозамбік",
    "Namibia" : "Намібія",
    "New Caledonia" : "Нова Каледонія ",
    "Niger" : "Нігер",
    "Norfolk Island" : "Острів Норфолк ",
    "Nigeria" : "Нігерія",
    "Nicaragua" : "Нікарагуа",
    "Netherlands" : "Нідерланди",
    "Norway" : "Норвегія",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ніуе",
    "New Zealand" : "Нова Зеландія ",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Французька Полінезія ",
    "Papua New Guinea" : "Папуа-Нова Гвінея",
    "Philippines" : "Філіппіни",
    "Pakistan" : "Пакистан",
    "Poland" : "Польща",
    "Saint Pierre and Miquelon" : "Сен-П'єр і Мікелон ",
    "Pitcairn" : "Піткерн",
    "Puerto Rico" : "Пуерто-Ріко ",
    "Palestine" : "Палестина",
    "Portugal" : "Португалія",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюньйон",
    "Romania" : "Румунія",
    "Serbia" : "Сербія",
    "Russia" : "Росія",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудівська Аравія ",
    "Solomon Islands" : "Соломонові острови ",
    "Seychelles" : "Сейшельські острови ",
    "Sudan" : "Судан",
    "Sweden" : "Швеція",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "острова Святої Єлени, Вознесіння та Тристан-да-Кунья ",
    "Slovenia" : "Словенія",
    "Svalbard and Jan Mayen" : "Шпіцберген і Ян-Майєн ",
    "Slovakia" : "Словаччина",
    "Sierra Leone" : "Сьєрра-Леоне ",
    "San Marino" : "Сан-Марино ",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалі",
    "Suriname" : "Суринам",
    "South Sudan" : "Південний Судан ",
    "Sao Tome and Principe" : "Сан-Томе і Принсіпі ",
    "El Salvador" : "Сальвадор ",
    "Sint Maarten" : "Сінт-Мартен",
    "Syria" : "Сирія",
    "Swaziland" : "Свазіленд",
    "Turks and Caicos Islands" : "Острови Теркс і Кайкос ",
    "Chad" : "Чад",
    "Fr. S. Antarctic Lands" : "О. С. Антарктичні землі",
    "Togo" : "Того",
    "Thailand" : "Таїланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Тимор-Лешті ",
    "Turkmenistan" : "Туркменістан",
    "Tunisia" : "Туніс",
    "Tonga" : "Тонга",
    "Turkey" : "Туреччина",
    "Trinidad and Tobago" : "Тринідад і Тобаго ",
    "Tuvalu" : "Тувалу",
    "Taiwan" : "Тайвань",
    "Tanzania" : "Танзанія",
    "Ukraine" : "Україна",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Малі Віддалені Острови Сполучених Штатів Америки ",
    "United States" : "Сполучені Штати",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Святий Престол ",
    "Saint Vincent and the Grenadines" : "Сент-Вінсент і Гренадини ",
    "Venezuela" : "Венесуела",
    "Virgin Islands (British)" : "Віргінські острови (Британські) ",
    "Virgin Islands (U.S.)" : "Віргінські острови (США) ",
    "Vietnam" : "В'єтнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уолліс і Футуна ",
    "Samoa" : "Самоа",
    "Yemen" : "Ємен",
    "Mayotte" : "Майотта",
    "South Africa" : "Півде́нно-Африка́нська Респу́бліка",
    "Zambia" : "Замбія",
    "Zimbabwe" : "Зімбабве",
    "Your %s account" : "Ваш %s аккаунт",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Ваші дані вказують на те, ким ви є, і ними можна легко зловживати. Ми в Nextcloud вважаємо, що ви маєте право вирішувати, що станеться з вашими даними. Nextcloud захищає ваші права, як визначено в Маніфесті даних користувача!",
    "User Data Manifesto 2.0" : "Маніфест даних користувача 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Визначення основних прав людей на контроль власних даних в епоху Інтернету",
    "Control" : "Контроль",
    "over user data access" : "через доступ до даних користувача",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Дані, явно та добровільно завантажені користувачем, повинні перебувати під повним контролем користувача. Користувачі повинні мати можливість вирішувати, кому надавати прямий доступ до своїх даних і з якими дозволами та ліцензіями такий доступ слід надавати.",
    "Knowledge" : "Знання",
    "of how the data is stored" : "про те, як зберігаються дані",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Коли дані завантажуються до певного постачальника послуг, користувачі повинні бути проінформовані про те, де цей конкретний постачальник послуг зберігає дані, як довго, у якій юрисдикції працює конкретний постачальник послуг і які закони застосовуються.",
    "Freedom" : "Свобода",
    "to choose a platform" : "вибрати платформу",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Користувачі завжди повинні мати можливість витягувати свої дані зі служби в будь-який час, не зазнаючи блокування від постачальника. Для цього необхідні відкриті стандарти для форматів і протоколів.",
    "Learn more ↗" : "Дізнайтеся більше ↗",
    "Where is your data?" : "Де ваші дані?",
    "Who has access to your data?" : "Хто має доступ до ваших даних?",
    "Administrators" : "Адміністратори",
    "People you shared with" : "Люди, з якими ви поділилися",
    "Privacy policy" : "Політика конфіденційності",
    "Read the privacy policy." : "Переглянути політику конфіденційності.",
    "Encryption" : "Шифрування",
    "The admin hasn't selected the location of the server yet." : "Адміністратор ще не вибрав місце розташування сервера."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
